Object store Methods — Rucio 1.2 documentation

# Object store Methods

class `rucio.client.objectstoreclient.` `ObjectStoreClient`(rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=None, user_agent='rucio-clients')

  Bases: `rucio.client.baseclient.BaseClient`

  Replica client class for working with replicas

  `OBJECTSTORE_BASEURL` = 'objectstores'
  `connect`(rse, url)

    Parameters: | rse – RSE name. url – URL string.
    Returns: | OK.

  `get_metadata`(urls, rse)

    Parameters: | ruls – List of URLs. rse – RSE name.
    Returns: | Dictionary of metadata refering to the files.

  `get_signed_url`(url, rse, operation='read')

    Parameters: | url – URL string. rse – RSE name.
    Returns: | A signed URL refering to the file.

  `get_signed_urls`(urls, rse, operation='read')

    Parameters: | ruls – List of URLs. rse – RSE name.
    Returns: | URL dictionaries refering to the files.

  `rename`(pfn, new_pfn, rse)

    Parameters: | rul – URL string. new_rul – URL string. rse – RSE name.
    Returns: | Dictionary of metadata refering to the files.